<?php
class imagetools extends plxPlugin {
	public function __construct($default_lang) {
		# appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		# Déclaration des hooks
		
		$this->addHook('AdminMediasTop', 'AdminMediasTop');
		$this->addHook('AdminMediasPrepend', 'AdminMediasPrepend');
	}

	/**
	 * Méthode qui ajoute des options dans les opérations applicables aux images
	 *
	 * @author	Rémi AUGUSTE
	 **/
	public function AdminMediasTop() {
		global $selectionList;
		$myselection = array('' =>L_FOR_SELECTION, 'right'=>$this->getLang('L_ROTATE_RIGHT'), 'left'=>$this->getLang('L_ROTATE_LEFT'));
		$selectionList = array_merge($myselection, $selectionList);
	}
	
	/**
	 * Méthode qui applique une rotation à une liste d'images
	 *
	 * @param	path		chemin absolu menant au dossier des images à traiter
	 * @param	files		liste des fichiers à traiter
	 * @param	angle		angle de rotation à appliquer dans le sens géométrique (anti-horaire)
 	 * @return	boolean		faux si erreur sinon vrai
	 * @author	Rémi AUGUSTE
	 **/
	public function rotateImages($path, $files, $angle)
	{
		$count = 0;
		foreach($files as $file)
		{
			$file=basename($file);
			if(is_file($path.$file))
			{
				$ext = strtolower(strrchr($path.$file,'.'));
				if(in_array($ext, array('.gif', '.jpg', '.png')))
				{
					if($this->applyRotation($path.$file, $angle, 80))
						$count++;
				}
			}
		}

		if(sizeof($files)==1) {
			if($count==0)
				return plxMsg::Error($this->getLang('L_IMAGETOOLS_ROTATE_IMAGE_ERR'));
			else
				return plxMsg::Info($this->getLang('L_IMAGETOOLS_ROTATE_IMAGE_SUCCESSFUL'));
		}
		else {
			if($count==0)
				return plxMsg::Error($this->getLang('L_IMAGETOOLS_ROTATE_IMAGE_ERR'));
			else
				return plxMsg::Info($this->getLang('L_IMAGETOOLS_ROTATE_IMAGE_SUCCESSFUL'));
		}		
	}
	
	/**
	 * Méthode qui applique une rotation à une image
	 *
	 * @param	filename			emplacement et nom du fichier source
	 * @param	angle				angle de rotation en degré à appliquer dans le sens géométrique (anti-horaire)
 	 * @param	quality				qualité de l'image
 	 * @return	boolean				vrai si la rotation a été appliquée et si l'image existe encore après la sauvegarde
	 * @author	Rémi AUGUSTE
	 **/
	private function applyRotation($filename, $angle, $quality)
	{
		$hasWorked = false;

		# Informations sur l'image
		list($width_orig,$height_orig,$type) = getimagesize($filename);

		if($type == 1)
		{
			$image = imagecreatefromgif($filename);
			$rotated = imagerotate($image, $angle, 0);
			if ($rotated)
				$hasWorked = true;
			imagegif($rotated, $filename);
		}
		elseif($type == 2)
		{
			$image = imagecreatefromjpeg($filename);
			$rotated = imagerotate($image, $angle, 0);
			if ($rotated)
				$hasWorked = true;
			imagejpeg($rotated, $filename, $quality);
		}
		elseif($type == 3)
		{
			$image = imagecreatefrompng($filename);
			$rotated = imagerotate($image, $angle, 0);
			if ($rotated)
				$hasWorked = true;
			imagepng($rotated, $filename);
		}
		
		return $hasWorked;
	}

	/**
	 * Méthode qui ajoute la prise en charge des opérations
	 *
	 * @author	Rémi AUGUSTE
	 **/
	public function AdminMediasPrepend()
	{	
		if(isset($_POST['selection']) AND ($_POST['selection'][0] == 'right' OR $_POST['selection'][1] == 'right') AND isset($_POST['idFile']))
		{
			$this->rotateImages(PLX_ROOT.$_SESSION['medias'].$_SESSION['folder'], $_POST['idFile'], -90);
		}
		elseif(isset($_POST['selection']) AND ($_POST['selection'][0] == 'left' OR $_POST['selection'][1] == 'left') AND isset($_POST['idFile'])) {
			$this->rotateImages(PLX_ROOT.$_SESSION['medias'].$_SESSION['folder'], $_POST['idFile'], 90);
		}
	}
}
?>

